function [p,rho,T,a]=atmos(z)

%funzione che calcola i valori atmosferici per una data altitudine
%NB valori presi con il sistema di misura SI
%input: z=altezza
%output: p=pressione, rho=densit, T=temperatura, a=velocit suono
%si basa sui profili ottenuti dal modello atmosferico degli US
n=length(z);
z=z/1000;
T=zeros(1,n);
p=zeros(1,n);
a=zeros(1,n);
rho=zeros(1,n);
R=287.053;
for i=1:n

if z(i)>=0 && z(i)<=11
    
    p(i)=101325*(288.15/(288.15-6.5*z(i)))^(34.1632/(-6.5));
    T(i)=288.15-6.5*z(i);
    
elseif z(i)>11 && z(i)<=20
    
    T(i)=216.65;
    p(i)=22632.06*exp(-34.1632*(z(i)-11)/216.65);
    
elseif z(i)>20 && z(i)<=32
    
    T(i)=196.65+z(i);
    p(i)=5474.889*(216.65/(216.65+(z(i)-20)))^34.1632;
    
elseif z(i)>32 && z(i)<=47
    
    T(i)=139.05+2.8*z(i);
    p(i)=868.0187*(228.65/(228.65+2.8*(z(i)-32)))^(34.1632/2.8);
    
elseif z(i)>47 && z(i)<=51
    
    T(i)=270.65;
    p(i)=110.9063*exp(-34.1632*(z(i)-47)/270.65);
    
elseif z(i)>51 && z(i)<=71
    
    T(i)=413.45-2.8*z(i);
    p(i)=66.93887*(270.65/(270.65-2.8*(z(i)-51)))^(34.1632/(-2.8));
    
elseif z(i)>71 && z(i)<=86
    
    T(i)=356.65-2*z(i);
    p(i)=3.95642*(214.65/(214.65-2*(z(i)-71)))^(34.1632/(-2));
    
else
    
    if z(i)>86 && z(i)<=91
        
        T(i)=186.8673;
        A=0;
        B=2.159582e-6;
        C=-4.836957e-4;
        D=-0.1425192;
        E=13.4753;
        AR=0;
        BR=-3.322622e-6;
        CR=9.11146e-4;
        DR=-0.2609971;
        ER=5.944694;
        
    elseif z(i)>91 && z(i)<=100
        
        T(i)=263.1905-76.3232*sqrt(1-((z(i)-91)/(-19.9429))^2);
        A=0;
        B=3.304895e-5;
        C=-0.009062730;
        D=0.6516698;
        E=-11.03037;
        AR=0;
        BR=2.873405e-5;
        CR=-0.008492037;
        DR=0.6541179;
        ER=-11.03037;
        
    elseif z(i)>100 && z(i)<=110
        
        T(i)=263.1905-76.3232*sqrt(1-((z(i)-91)/(-19.9429))^2);
        A=0;
        B=6.693926e-5;
        C=-0.01945388;
        D=1.719080;
        E=-47.75030;
        AR=-1.340774e-5;
        BR=0.005162063;
        CR=-0.8048342;
        DR=55.55996;
        ER=-1443.338;
        
    elseif z(i)>110 && z(i)<120
        
        T(i)=240+12*(z(i)-110);
        A=0;
        B=-6.539316e-5;
        C=0.02485568;
        D=-3.22362;
        E=135.9355;
        AR=0;
        BR=-8.854164e-5;
        CR=0.03373254;
        DR=-4.390837;
        ER=176.5294;
        
    else
        
        csi=(z(i)-120)*(6356.766+120)/(6356.766+z(i));
        T(i)=1000-640*exp(-0.01875*csi);
        A=2.283506e-7;
        B=-1.343221e-4;
        C=0.02999016;
        D=-3.055446;
        E=113.5764;
        AR=3.661771e-7;
        BR=-2.154344e-4;
        CR=0.04809214;
        DR=-4.884744;
        ER=172.3597;
        
    end
 
    p(i)=exp(A*z(i)^4+B*z(i)^3+C*z(i)^2+D*z(i)+E);
    rho(i)=exp(AR*z(i)^4+BR*z(i)^3+CR*z(i)^2+DR*z(i)+ER);
end

rho(i)=p(i)/(R*T(i));
a(i)=sqrt(0.25*R*T(i));
end
end